@@ -238,6 +238,7 @@ def create_folders(project_name):
     create_main_folders('dsp', 'tester')
     create_main_folders('trainer', 'main')
     create_main_folders('server', 'main')
+    create_main_folders('documentation', 'main')
 
 
 def create_project(project_name):
@@ -282,6 +283,7 @@ def create_project(project_name):
     create_server_config_json()
     copy_deploy_files(directories['main'])
     copy_cloud_eval_files(directories['main'])
+    copy_documentation_files(directories['documentation'])
 
     change_to_project_dir()
     run_dvc_init()
@@ -314,6 +316,7 @@ def create_tester_file(project_name, folder, test_file_type, createInitFile=True
     data = read_template_file('tester/' + test_file_type)
     replace_in_template_and_create_file(project_name, folder, test_file_type, data, createInitFile)
 
+
 def create_dsp_file(project_name, folder, test_file_type, createInitFile=True):
     data = read_template_file('tester/dsp/' + test_file_type)
     replace_in_template_and_create_file(project_name, folder, test_file_type, data, createInitFile)
@@ -653,16 +656,16 @@ def copy_cloud_eval_files(main_dir):
     service_folder = str(currentPipelineFolder)
     service_name = service_folder.split('/')[-1]
     project_name_no_underscore = clean_existing_project_name(service_name)
-    dir = os.path.join(__location__, 'dsframework/cli/tester/cloud_eval/')
+    cloud_eval_dir = os.path.join(__location__, 'dsframework/cli/tester/cloud_eval/')
     listOfFiles = list()
     conflicted_files = []
-    for (dirpath, dirname, filenames) in os.walk(dir):
+    for (dirpath, dirname, filenames) in os.walk(cloud_eval_dir):
         if "__pycache__" in dirpath:
             continue
-        dirpath = dirpath.replace(dir, '')
+        dirpath = dirpath.replace(cloud_eval_dir, '')
         listOfFiles += [os.path.join(dirpath, file) for file in filenames]
         for file_path in listOfFiles:
-            framework_source_file = os.path.join(dir, file_path)
+            framework_source_file = os.path.join(cloud_eval_dir, file_path)
             with open(framework_source_file, 'r', encoding="utf8") as file:
                 try:
                     data = file.read()
@@ -705,6 +708,16 @@ def copy_cloud_eval_files(main_dir):
             print(f"Existing: [{conflicted_file[0]}] \t\t Framework source file [{conflicted_file[1]}]")
 
 
+def copy_documentation_files(target_dir):
+    source_dir = os.path.join(__location__, 'documentation/')
+
+    for (dirpath, dirname, filenames) in os.walk(source_dir):
+        doc_files = [os.path.join(dirpath, file) for file in filenames if file != 'dsf_doxyfile']
+
+        for file_path in doc_files:
+            shutil.copy2(file_path, target_dir)
+
+
 def to_capitalize_no_underscore(text):
     return ''.join(elem.capitalize() for elem in text.split('_'))
 
@@ -713,10 +726,11 @@ def clean_existing_project_name(text):
     no_underscore_text = to_capitalize_no_underscore(text)
     return ''.join(elem.capitalize() for elem in no_underscore_text.split('-'))
 
+
 def let_user_pick(options):
     print("Please choose:")
     for idx, element in enumerate(options):
-        print("{}) {}".format(idx+1,element))
+        print("{}) {}".format(idx+1, element))
     i = input("Enter number: ")
     try:
         if 0 < int(i) <= len(options):
